@@ -46,7 +46,6 @@
 #
 # END BPS TAGGED BLOCK }}}
 
-# This Action will open the BASE if a dependent is resolved.
 package RT::Action::AutoOpen;
 
 use strict;
@@ -87,7 +86,7 @@ sub Prepare {
 
     # no change if the ticket is in initial status and the message is a mail
     # from a requestor
-    return 1 if $ticket->QueueObj->Lifecycle->IsInitial($ticket->Status)
+    return 1 if $ticket->LifecycleObj->IsInitial($ticket->Status)
         && $self->TransactionObj->IsInbound;
 
     if ( my $msg = $self->TransactionObj->Message->First ) {
