@@ -59,11 +59,12 @@ been started, to make a comment on the ticket.
 
 =head1 SYNOPSIS
 
-my $action_obj = RT::Action::RecordComment->new('TicketObj'   => $ticket_obj,
-						'TemplateObj' => $template_obj,
-						);
-my $result = $action_obj->Prepare();
-$action_obj->Commit() if $result;
+    my $action_obj = RT::Action::RecordComment->new(
+        'TicketObj'   => $ticket_obj,
+        'TemplateObj' => $template_obj,
+    );
+    my $result = $action_obj->Prepare();
+    $action_obj->Commit() if $result;
 
 =head1 METHODS
 
@@ -79,8 +80,8 @@ will give us a loop.
 sub Prepare {
     my $self = shift;
     if (defined $self->{'TransactionObj'} &&
-	$self->{'TransactionObj'}->Type =~ /^(Comment|Correspond)$/) {
-	return undef;
+        $self->{'TransactionObj'}->Type =~ /^(Comment|Correspond)$/) {
+        return undef;
     }
     return 1;
 }
@@ -103,14 +104,14 @@ sub CreateTransaction {
     my $self = shift;
 
     my ($result, $msg) = $self->{'TemplateObj'}->Parse(
-	TicketObj => $self->{'TicketObj'});
+        TicketObj => $self->{'TicketObj'});
     return undef unless $result;
-    
+
     my ($trans, $desc, $transaction) = $self->{'TicketObj'}->Comment(
-	MIMEObj => $self->TemplateObj->MIMEObj);
+        MIMEObj => $self->TemplateObj->MIMEObj);
     $self->{'TransactionObj'} = $transaction;
 }
-    
+
 
 RT::Base->_ImportOverlays();
 
