@@ -75,7 +75,7 @@ sub Commit {    # XXX: from custom prepare code
 
         $rejected->Correspond( MIMEObj => $template->MIMEObj );
         $rejected->SetStatus(
-            Status => $rejected->QueueObj->Lifecycle->DefaultStatus('denied') || 'rejected',
+            Status => $rejected->LifecycleObj->DefaultStatus('denied') || 'rejected',
             Force  => 1,
         );
     }
