@@ -122,7 +122,7 @@ to this object's CurrentUser->LanguageHandle for localization.
 
 you call it like this:
 
-    $self->loc("I have [quant,_1,concrete mixer].", 6);
+    $self->loc("I have [quant,_1,concrete mixer,concrete mixers].", 6);
 
 In english, this would return:
     I have 6 concrete mixers.
