@@ -51,12 +51,10 @@ package RT::CustomFieldValues;
 use strict;
 use warnings;
 
-
+use base 'RT::SearchBuilder';
 
 use RT::CustomFieldValue;
 
-use base 'RT::SearchBuilder';
-
 sub Table { 'CustomFieldValues'}
 
 sub _Init {
@@ -64,15 +62,15 @@ sub _Init {
 
   # By default, order by SortOrder
   $self->OrderByCols(
-	 { ALIAS => 'main',
-	   FIELD => 'SortOrder',
-	   ORDER => 'ASC' },
-	 { ALIAS => 'main',
-	   FIELD => 'Name',
-	   ORDER => 'ASC' },
-	 { ALIAS => 'main',
-	   FIELD => 'id',
-	   ORDER => 'ASC' },
+         { ALIAS => 'main',
+           FIELD => 'SortOrder',
+           ORDER => 'ASC' },
+         { ALIAS => 'main',
+           FIELD => 'Name',
+           ORDER => 'ASC' },
+         { ALIAS => 'main',
+           FIELD => 'id',
+           ORDER => 'ASC' },
      );
 
     return ( $self->SUPER::_Init(@_) );
@@ -95,19 +93,6 @@ sub LimitToCustomField {
     );
 }
 
-
-
-
-=head2 NewItem
-
-Returns an empty new RT::CustomFieldValue item
-
-=cut
-
-sub NewItem {
-    my $self = shift;
-    return(RT::CustomFieldValue->new($self->CurrentUser));
-}
 RT::Base->_ImportOverlays();
 
 1;
