@@ -84,29 +84,19 @@ sub LimitToType  {
   my $self = shift;
   my $type = shift;
   $self->Limit (ENTRYAGGREGATOR => 'OR',
-		FIELD => 'Type',
-		VALUE => "$type")
+                FIELD => 'Type',
+                VALUE => "$type")
       if defined $type;
   $self->Limit (ENTRYAGGREGATOR => 'OR',
-		FIELD => 'Type',
-		VALUE => "Correspond")
+                FIELD => 'Type',
+                VALUE => "Correspond")
       if $type eq "Create";
   $self->Limit (ENTRYAGGREGATOR => 'OR',
-		FIELD => 'Type',
-		VALUE => 'any');
-  
+                FIELD => 'Type',
+                VALUE => 'any');
+
 }
 
-=head2 NewItem
-
-Returns an empty new RT::ScripAction item
-
-=cut
-
-sub NewItem {
-    my $self = shift;
-    return(RT::ScripAction->new($self->CurrentUser));
-}
 RT::Base->_ImportOverlays();
 
 1;
