@@ -79,15 +79,20 @@ be selected for deletion. Identifier is name of user defined group
 or id of a group, as well C<Privileged> or <unprivileged> can used
 to select people from system groups.
 
+=head2 not_member_of - group identifier
+
+Like member_of, but selects users who are not members of the provided
+group.
+
 =head2 replace_relations - user identifier
 
-When you delete user there are could be minor links to him in RT DB.
-This option allow you to replace this links with link to other user.
-This links are Creator and LastUpdatedBy, but NOT any watcher roles,
-this means that if user is watcher(Requestor, Owner,
-Cc or AdminCc) of the ticket or queue then link would be deleted.
+When you delete an user there could be minor links to them in the RT database.
+This option allow you to replace these links with links to the new user.
+The replaceable links are Creator and LastUpdatedBy, but NOT any watcher roles.
+This means that if the user is a watcher(Requestor, Owner,
+Cc or AdminCc) of the ticket or queue then the link would be deleted.
 
-This argument could be user id or name.
+This argument could be an user id or name.
 
 =head2 no_tickets - boolean
 
@@ -108,7 +113,7 @@ want to use C<replace_relations> option.
 sub SupportArgs
 {
     return $_[0]->SUPER::SupportArgs,
-           qw(status name email member_of replace_relations no_tickets);
+           qw(status name email member_of not_member_of replace_relations no_tickets);
 }
 
 sub TestArgs
@@ -128,19 +133,22 @@ sub TestArgs
     if( $args{'name'} ) {
         $args{'name'} = $self->ConvertMaskToSQL( $args{'name'} );
     }
-    if( $args{'member_of'} ) {
-        my $group = RT::Group->new( RT->SystemUser );
-        if ( $args{'member_of'} =~ /^(Everyone|Privileged|Unprivileged)$/i ) {
-            $group->LoadSystemInternalGroup( $args{'member_of'} );
-        }
-        else {
-            $group->LoadUserDefinedGroup( $args{'member_of'} );
-        }
-        unless ( $group->id ) {
-            return (0, "Couldn't load group '$args{'member_of'}'" );
-        }
-        $args{'member_of'} = $group->id;
+    if( $args{'member_of'} or $args{'not_member_of'} ) {
+        foreach my $group_option ( qw(member_of not_member_of) ){
+            next unless $args{$group_option};
 
+            my $group = RT::Group->new( RT->SystemUser );
+            if ( $args{$group_option} =~ /^(Everyone|Privileged|Unprivileged)$/i ) {
+                $group->LoadSystemInternalGroup( $args{$group_option} );
+            }
+            else {
+                $group->LoadUserDefinedGroup( $args{$group_option} );
+            }
+            unless ( $group->id ) {
+                return (0, "Couldn't load group '$args{$group_option}'" );
+            }
+            $args{$group_option} = $group->id;
+        }
     }
     if( $args{'replace_relations'} ) {
         my $uid = $args{'replace_relations'};
@@ -189,15 +197,32 @@ sub Run
     if( $self->{'opt'}{'member_of'} ) {
         $objs->MemberOfGroup( $self->{'opt'}{'member_of'} );
     }
-    if( $self->{'opt'}{'no_tickets'} ) {
-        return $self->FilterWithoutTickets(
+    my @filter;
+    if( $self->{'opt'}{'not_member_of'} ) {
+        push @filter, $self->FilterNotMemberOfGroup(
             Shredder => $args{'Shredder'},
-            Objects  => $objs,
+            GroupId  => $self->{'opt'}{'not_member_of'},
         );
-    } else {
-        if( $self->{'opt'}{'limit'} ) {
-            $objs->RowsPerPage( $self->{'opt'}{'limit'} );
+    }
+    if( $self->{'opt'}{'no_tickets'} ) {
+        push @filter, $self->FilterWithoutTickets(
+            Shredder => $args{'Shredder'},
+        );
+    }
+
+    if (@filter) {
+        $self->FetchNext( $objs, 'init' );
+        my @res;
+        USER: while ( my $user = $self->FetchNext( $objs ) ) {
+            for my $filter (@filter) {
+                next USER unless $filter->($user);
+            }
+            push @res, $user;
+            last if $self->{'opt'}{'limit'} && @res >= $self->{'opt'}{'limit'};
         }
+        $objs = \@res;
+    } elsif ( $self->{'opt'}{'limit'} ) {
+        $objs->RowsPerPage( $self->{'opt'}{'limit'} );
     }
     return (1, $objs);
 }
@@ -222,6 +247,23 @@ sub SetResolvers
     return (1);
 }
 
+sub FilterNotMemberOfGroup {
+    my $self = shift;
+    my %args = (
+        Shredder => undef,
+        GroupId  => undef,
+        @_,
+    );
+
+    my $group = RT::Group->new(RT->SystemUser);
+    $group->Load($args{'GroupId'});
+
+    return sub {
+        my $user = shift;
+        not $group->HasMemberRecursively($user->id);
+    };
+}
+
 sub FilterWithoutTickets {
     my $self = shift;
     my %args = (
@@ -229,19 +271,16 @@ sub FilterWithoutTickets {
         Objects  => undef,
         @_,
     );
-    my $users = $args{Objects};
-    $self->FetchNext( $users, 'init' );
 
-    my @res;
-    while ( my $user = $self->FetchNext( $users ) ) {
-        push @res, $user if $self->_WithoutTickets( $user );
-        return (1, \@res) if $self->{'opt'}{'limit'} && @res >= $self->{'opt'}{'limit'};
-    }
-    return (1, \@res);
+    return sub {
+        my $user = shift;
+        $self->_WithoutTickets( $user )
+    };
 }
 
 sub _WithoutTickets {
     my ($self, $user) = @_;
+    return unless $user and $user->Id;
     my $tickets = RT::Tickets->new( RT->SystemUser );
     $tickets->{'allow_deleted_search'} = 1;
     $tickets->FromSQL( 'Watcher.id = '. $user->id );
