@@ -103,18 +103,6 @@ sub LimitToKids {
 
 # }}}
 
-=head2 NewItem
-
-Returns an empty new RT::Topic item
-
-=cut
-
-sub NewItem {
-    my $self = shift;
-    return(RT::Topic->new($self->CurrentUser));
-}
-
-
 RT::Base->_ImportOverlays();
 
 1;
